#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.5.1
visibility:           public
id:                   rank2classes-1.5.5.1-1zVzYy1gwduL5orpgd0Tx
key:                  rank2classes-1.5.5.1-1zVzYy1gwduL5orpgd0Tx
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  7ed8000594ce7d38903444ed62e733fd
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.5.1-1zVzYy1gwduL5orpgd0Tx
depends:
    base-4.18.2.1 data-functor-logistic-0.0-1q58NGsh44eJ2MkPID6Lqu
    distributive-0.6.3-86aMf1NY2SkAshQXjPjSQp template-haskell-2.20.0.0
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-rank2classes-z-doctests
version:              1.5.5.1
package-name:         rank2classes
lib-name:             doctests
id:                   rank2classes-1.5.5.1-nwDbCkhv0OIS1uytf1Rty-doctests
key:                  rank2classes-1.5.5.1-nwDbCkhv0OIS1uytf1Rty-doctests
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  6f78e70309fb6303857b6a05d0c7aa3c
hidden-modules:       MyModule
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.5.1-nwDbCkhv0OIS1uytf1Rty-doctests
depends:
    base-4.18.2.1 rank2classes-1.5.5.1-1zVzYy1gwduL5orpgd0Tx

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

